"""Console script for kyman."""
import logging
import os
import sys
from argparse import ArgumentParser

from . import kyman

filename = os.path.basename(__file__)[:-3]

logger = logging.getLogger(filename)


def create_parser():
    parser = ArgumentParser(description="Python Tools for Kafka object management.")
    parser.add_argument(
        "--dry-run",
        help="Do not execute commands, just output the requests.",
        action="store_true",
        default=False,
    )
    parser.add_argument(
        "-k",
        "--insecure",
        help="Allow unverified HTTPS request to host.",
        action="store_true",
        default=False,
    )
    parser.add_argument(
        "-o",
        "--output-format",
        help="Output format (json, yaml).",
        nargs=1,
        metavar=("OUTPUT_FORMAT"),
        choices=["json", "yaml"],
        action="store",
        required=False,
        default="json",
    )
    return parser


def main():
    """Console script for kyman."""
    parser = create_parser()
    args = parser.parse_args()
    os.environ["KYMAN_DRY_RUN"] = str(args.dry_run)
    os.environ["KYMAN_INSECURE"] = str(args.insecure)
    os.environ["KYMAN_OUTPUT_FORMAT"] = str(args.output_format)
    return kyman.main()


if __name__ == "__main__":
    sys.exit(main())  # pragma: no cover
