import base64
import logging
import os

import requests

from .utils import memoize, profile

filename = os.path.basename(__file__)[:-3]

logger = logging.getLogger(filename)


def encode_token():
    username = os.getenv("IDENTITY_USERNAME")
    password = os.getenv("IDENTITY_PASSWORD")
    token = base64.b64encode(f"{username}:{password}".encode())
    return token.decode()


@profile
@memoize
def get_identity_v2_token():
    logger.debug("get_identity_v2_token()")
    identity_v2_token_url = os.getenv(
        "IDENTITY_V2_TOKEN_URL",
        "https://login-dev.ultipro.com/v2/oauth2/us_internal/access_token",
    )
    payload = "grant_type=client_credentials&scope=openid%20profile"
    headers = {
        "Content-Type": "application/x-www-form-urlencoded",
        "Authorization": f"Basic {encode_token()}",
        "Cookie": "ha_backend_openam=s0.0.1935-3",
    }
    response = requests.request(
        "POST", identity_v2_token_url, headers=headers, data=payload
    )
    response.raise_for_status()
    if response.status_code == 200:
        response_json = response.json()
        logger.debug(f"response_json: {response_json}")
        access_token = response_json["access_token"]
        logger.debug(f"get_identity_v2_token()->({access_token})")
        return access_token
